#!/bin/sh
#
# Linux-HA: CIM Provider register tool 
#
# Author: Jia Ming Pan <jmltc@cn.ibm.com>
# Copyright (c) 2005 International Business Machines
# Licensed under the GNU GPL.
#
#

sh /usr/lib64/heartbeat/cim/do_register.sh -t  \
-r /usr/lib64/heartbeat/cim/LinuxHA.reg \
-m /usr/lib64/heartbeat/cim/LinuxHA.mof

